netapp_ontap.models.ipsec_policy_response_records API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ipsec_policy_response_records`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IpsecPolicyResponseRecordsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IpsecPolicyResponseRecords object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `action: str GET POST`

    Action for the IPsec policy.

    Valid choices:

    - bypass
    - discard
    - esp_transport
    - esp_udp
  `authentication_method: str GET POST`

    Authentication method for the IPsec policy.

    Valid choices:

    - none
    - psk
    - pki
  `certificate: SecurityCertificate GET POST PATCH`

    The certificate field of the ipsec_policy_response_records.

  `certificate_modify_keepsa: bool GET POST PATCH`

    Indicates whether old security associations are kept upon certificate modification.

  `enabled: bool GET POST PATCH`

    Indicates whether or not the policy is enabled.

  `ipspace: Ipspace GET POST`

    The ipspace field of the ipsec_policy_response_records.

  `local_endpoint: IpsecEndpoint GET POST PATCH`

    Endpoint specification for the IPsec policy

  `local_identity: str GET POST PATCH`

    Local Identity

  `name: str GET POST`

    IPsec policy name.

  `ppk: Ppk GET POST PATCH`

    Post-quantum pre-shared key information.

  `protocol: str GET POST PATCH`

    Lower layer protocol to be covered by the IPsec policy.

    Example: 17

  `remote_endpoint: IpsecEndpoint GET POST PATCH`

    Endpoint specification for the IPsec policy

  `remote_identity: str GET POST PATCH`

    Remote Identity

  `scope: str GET POST PATCH`

    The scope field of the ipsec_policy_response_records.

  `secret_key: str POST`

    Pre-shared key for IKE negotiation.

  `svm: Svm GET POST`

    The svm field of the ipsec_policy_response_records.

  `uuid: str GET`

    Unique identifier of the IPsec policy.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412